@@ -21,6 +21,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_ec2
@@ -52,6 +54,10 @@ class AlbArnTarget(
         :param alb_arn: The ARN of the application load balancer to load balance to.
         :param port: The port on which the target is listening.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AlbArnTarget.__init__)
+            check_type(argname="argument alb_arn", value=alb_arn, expected_type=type_hints["alb_arn"])
+            check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [alb_arn, port])
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
@@ -66,6 +72,9 @@ class AlbArnTarget(
 
         :param target_group: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AlbArnTarget.attach_to_network_target_group)
+            check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
 
@@ -124,6 +133,10 @@ class AlbTarget(
         :param alb: The application load balancer to load balance to.
         :param port: The port on which the target is listening.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AlbTarget.__init__)
+            check_type(argname="argument alb", value=alb, expected_type=type_hints["alb"])
+            check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [alb, port])
 
 
@@ -158,6 +171,10 @@ class InstanceIdTarget(
         :param instance_id: Instance ID of the instance to register to.
         :param port: Override the default port for the target group.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(InstanceIdTarget.__init__)
+            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
+            check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [instance_id, port])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
@@ -172,6 +189,9 @@ class InstanceIdTarget(
 
         :param target_group: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(InstanceIdTarget.attach_to_application_target_group)
+            check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
@@ -186,6 +206,9 @@ class InstanceIdTarget(
 
         :param target_group: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(InstanceIdTarget.attach_to_network_target_group)
+            check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
 
@@ -219,6 +242,10 @@ class InstanceTarget(
         :param instance: Instance to register to.
         :param port: Override the default port for the target group.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(InstanceTarget.__init__)
+            check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
+            check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [instance, port])
 
 
@@ -275,6 +302,11 @@ class IpTarget(
         :param port: Override the group's default port.
         :param availability_zone: Availability zone to send traffic from.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IpTarget.__init__)
+            check_type(argname="argument ip_address", value=ip_address, expected_type=type_hints["ip_address"])
+            check_type(argname="argument port", value=port, expected_type=type_hints["port"])
+            check_type(argname="argument availability_zone", value=availability_zone, expected_type=type_hints["availability_zone"])
         jsii.create(self.__class__, self, [ip_address, port, availability_zone])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
@@ -289,6 +321,9 @@ class IpTarget(
 
         :param target_group: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IpTarget.attach_to_application_target_group)
+            check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
@@ -303,6 +338,9 @@ class IpTarget(
 
         :param target_group: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IpTarget.attach_to_network_target_group)
+            check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
 
@@ -340,6 +378,9 @@ class LambdaTarget(
 
         :param fn: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaTarget.__init__)
+            check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         jsii.create(self.__class__, self, [fn])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
@@ -354,6 +395,9 @@ class LambdaTarget(
 
         :param target_group: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaTarget.attach_to_application_target_group)
+            check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
@@ -368,6 +412,9 @@ class LambdaTarget(
 
         :param target_group: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaTarget.attach_to_network_target_group)
+            check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
 
